@@ -39,6 +39,7 @@ async def _tts(args):
         args.rate,
         args.volume,
         customspeak=args.custom_ssml,
+        proxy=args.proxy,
     ):
         if i[2] is not None:
             if not args.write_media:
@@ -128,6 +129,10 @@ async def _main():
         "--write-subtitles",
         help="instead of stderr, send subtitle output to provided file",
     )
+    parser.add_argument(
+        "--proxy",
+        help="proxy",
+    )
     args = parser.parse_args()
 
     if args.list_voices:
